==> libdatetime-locale-perl_1.33.orig.tar.gz: DateTime-Locale-1.33/share/xh.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'week' W 'of' MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "xh",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mvu",
    "Bin",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Caw",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Mvulo",
    "Lwesibini",
    "Lwesithathu",
    "Lwesine",
    "Lwesihlanu",
    "Mgqibelo",
    "Cawe",
  ],
  day_stand_alone_abbreviated => [
    "Mvu",
    "Bin",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Caw",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Mvulo",
    "Lwesibini",
    "Lwesithathu",
    "Lwesine",
    "Lwesihlanu",
    "Mgqibelo",
    "Cawe",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "BC",
    "AD",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Xhosa",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mat",
    "Epr",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Janyuwari",
    "Februwari",
    "Matshi",
    "Epreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septemba",
    "Okthoba",
    "Novemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mat",
    "Epr",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Janyuwari",
    "Februwari",
    "Matshi",
    "Epreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septemba",
    "Okthoba",
    "Novemba",
    "Disemba",
  ],
  name => "Xhosa",
  native_language => "isiXhosa",
  native_name => "isiXhosa",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1 unyangantathu",
    "2 unyangantathu",
    "3 unyangantathu",
    "4 unyangantathu",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1 unyangantathu",
    "2 unyangantathu",
    "3 unyangantathu",
    "4 unyangantathu",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/xh.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    GyMd => "M/d/y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-one" => "'week' W 'of' MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "xh",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mvu",
    "Lwesb",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Caw",
  ],
  day_format_narrow => [
    "M",
    "Sb",
    "Tht",
    "Sin",
    "Hl",
    "Mgq",
    "C",
  ],
  day_format_wide => [
    "Mvulo",
    "Lwesibini",
    "Lwesithathu",
    "Lwesine",
    "Lwesihlanu",
    "Mgqibelo",
    "Cawe",
  ],
  day_stand_alone_abbreviated => [
    "Mvu",
    "Bin",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Caw",
  ],
  day_stand_alone_narrow => [
    "M",
    "Sb",
    "St",
    "Sin",
    "Hl",
    "Mgq",
    "C",
  ],
  day_stand_alone_wide => [
    "Mvulo",
    "Lwesibini",
    "Lwesithathu",
    "Lwesine",
    "Lwesihlanu",
    "Mgqibelo",
    "Cawe",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "BC",
    "AD",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Xhosa",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mat",
    "Epr",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sept",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Janyuwari",
    "Februwari",
    "Matshi",
    "Epreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septemba",
    "Okthobha",
    "Novemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mat",
    "Epr",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Janyuwari",
    "Februwari",
    "Matshi",
    "Epreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septemba",
    "Okthoba",
    "Novemba",
    "Disemba",
  ],
  name => "Xhosa",
  native_language => "IsiXhosa",
  native_name => "IsiXhosa",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "ikota yoku-1",
    "ikota yesi-2",
    "ikota yesi-3",
    "ikota yesi-4",
  ],
  quarter_stand_alone_abbreviated => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "ikota yoku-1",
    "ikota yesi-2",
    "ikota yesi-3",
    "ikota yesi-4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
